#!/bin/sh
# Run MPI latency/bandwidth test over range of parameters
# Mark Moraes, D. E. Shaw Research & Development, LLC
maxiter=50000		# for medium latency (GigE: 50usec or so)
maxiter=1000000	# for low latency (Altix, Quadrics, Infiniband, Myrinet)
nvals="1 500 1000"
maxnodes=1024
case "$maxnodes" in 
0|'')	echo "Error: lamnodes returned \"$maxnodes\"" >&2; exit 1;;
esac
maxneighbours=128
for ov in 1 2 3; do
	kn=1
	while test $kn -le $maxneighbours; do
		k=$maxnodes
		while test $k -le $maxnodes; do
			for i in $nvals; do
				# scale iter down a bit as we increase the size of the exchange
				iter=`awk 'BEGIN {i = '$i'; maxiter='$maxiter'; if (i > 1) print int(maxiter / log(i) / 2.303 + 1); else print maxiter; }'`
				echo "echo \">>> $k processors: floats=$i iterations=$iter overlap=$ov neighbours=$kn\""
				echo mpirun -np $k ./mpi_latency $i $iter $ov $kn
			done
			nk=`expr $k \* 2`
			if test $k -lt $maxnodes -a $nk -gt $maxnodes; then
				k=$maxnodes
			else
				k=$nk
			fi
		done
		nk=`expr $kn \* 2`
		if test $kn -lt $maxneighbours -a $nk -gt $maxneighbours; then
			kn=$maxneighbours
		else
			kn=$nk
		fi
	done
done
